=======
genbox
=======

`` genbox`` is the input data generator for ``boxmox``

Documentation
=============

maintained at https://boxmodeling.meteo.physik.uni-muenchen.de/documentation

Installation
============